@@ -1,16 +1,18 @@
 def pytest_addoption(parser):
-    parser.addoption("--path", type=str, default="results/exp/Scan_1986.cxi",
-                     help="Path to a CXI file")
-    parser.addoption("--roi", type=int, nargs=4, default=(0, 1, 360, 1090),
+    parser.addoption("--scan_num", type=int, default=3985,
+                     help="Scan number")
+    parser.addoption("--roi", type=int, nargs=4, default=(270, 310, 350, 1280),
                      help="Region of interest")
-    parser.addoption("--defocus", type=float, default=1.0e-4,
+    parser.addoption("--defocus", type=float, default=152e-6,
+                     help="Defocus distance [m]")
+    parser.addoption("--alpha", type=float, default=0.1584,
                      help="Defocus distance [m]")
 
 def pytest_generate_tests(metafunc):
     # This is called for every test. Only get/set command line arguments
     # if the argument is specified in the list of test "fixturenames".
     option_dict = vars(metafunc.config.option)
-    for attr in ('path', 'roi', 'defocus'):
+    for attr in ('scan_num', 'roi', 'defocus', 'alpha'):
         option_value = option_dict.get(attr)
         if attr in metafunc.fixturenames and option_value is not None:
             metafunc.parametrize(attr, [option_value])
